pub struct FileClient { /* private fields */ }Expand description
An async FTPS file client, similar to the Python version using curl. It can list files in a directory and download specific files.
Implementations
Sourceimpl FileClient
impl FileClient
Sourcepub fn new(hostname: impl Into<String>, access_code: impl Into<String>) -> Self
pub fn new(hostname: impl Into<String>, access_code: impl Into<String>) -> Self
Create a new FileClient.
hostname: The FTP(S) server hostname.access_code: The password to use with user “bblp”.serial: Some identifier (unused in this snippet, but kept for parity).insecure: Iftrue, client will skip certificate validation.